@@ -21,7 +21,7 @@ use \Sabre\DAV;
  * @license  http://www.horde.org/licenses/bsd BSD
  * @package  Dav
  */
-class Horde_Dav_File extends Sabre\DAV\File
+class Horde_Dav_File extends Sabre\DAV\File implements DAV\IProperties
 {
     /**
      * A registry object.
@@ -54,6 +54,19 @@ class Horde_Dav_File extends Sabre\DAV\File
      */
     protected $_size;
 
+    /**
+     * Mapping of WebDAV property names to Horde API's browse() properties.
+     *
+     * @var array
+     */
+    protected static $_propertyMap = array(
+        '{DAV:}getcontentlength'            => 'contentlength',
+        '{DAV:}getcontenttype'              => 'contentype',
+        '{DAV:}getetag'                     => 'etag',
+        '{DAV:}owner'                       => 'owner',
+        '{http://sabredav.org/ns}read-only' => 'read-only',
+    );
+
     /**
      * Constructor.
      *
@@ -129,6 +142,7 @@ class Horde_Dav_File extends Sabre\DAV\File
     {
         list($base) = explode('/', $this->_path);
         try {
+            rewind($data);
             $this->_registry->callByPackage(
                 $base,
                 'put',
@@ -212,4 +226,42 @@ class Horde_Dav_File extends Sabre\DAV\File
             ? $this->_item['contenttype']
             : null;
     }
+
+    /**
+     * Updates properties on this node.
+     *
+     * @param array $mutations
+     * @return bool|array
+     */
+    public function updateProperties($mutations)
+    {
+        return false;
+    }
+
+    /**
+     * Returns a list of properties for this nodes.
+     *
+     * @param array $properties
+     * @return void
+     */
+    public function getProperties($properties)
+    {
+        $response = array();
+        foreach (self::$_propertyMap as $property => $apiProperty) {
+            if (isset($this->_item[$apiProperty])) {
+                $response[$property] = $this->_item[$apiProperty];
+            }
+        }
+        if (isset($this->_item['modified'])) {
+            $response['{DAV:}getlastmodified'] = new DAV\Property\GetLastModified(
+                $this->_item['modified']
+            );
+        }
+        if (isset($this->_item['displayname'])) {
+            $response['{DAV:}displayname'] = $this->_item['displayname'];
+        } elseif (isset($this->_item['name'])) {
+            $response['{DAV:}displayname'] = $this->_item['name'];
+        }
+        return $response;
+    }
 }
